@@ -34,6 +34,7 @@
 #include <IDevice.h>
 
 #include <QtGui>
+#include <algorithm>
 
 #pragma pack(1)
 
@@ -412,6 +413,9 @@ bool CGarminDBMap::registerMap(map_t& map)
         ++tile;
     }
 
+    /* Put here so the submap check doesn't do the basemap again. */
+    QMap<QString,subfile_desc_t>::const_iterator basemap;
+
     // read base map for maplevels
     try
     {
@@ -421,12 +425,29 @@ bool CGarminDBMap::registerMap(map_t& map)
         }
         map.base.push_back(map.img);
 
-        const QMap<QString,subfile_desc_t>& subfiles                 = map.img->getSubFiles();
-        QMap<QString,subfile_desc_t>::const_iterator subfile         = subfiles.begin();
+        const QMap<QString,subfile_desc_t>& subfiles = map.img->getSubFiles();
+        QMap<QString,subfile_desc_t>::const_iterator subfile = subfiles.begin();
+        quint8 fewest_map_bits = 0xFF;
 
-        QVector<subfile_desc_t::maplevel_t>::const_iterator maplevel = subfile->maplevels.begin();
-        while(maplevel != subfile->maplevels.end()) {
-            if(!maplevel->inherited) {
+        /* Find best candidate for basemap. */
+        while (subfile != subfiles.end()) {
+            QVector<subfile_desc_t::maplevel_t>::const_iterator maplevel = subfile->maplevels.begin();
+            /* Skip any upper levels that contain no real data. */
+            while (!maplevel->inherited){
+                ++maplevel;
+            }
+            /* Check for the least detailed map. */
+            if (maplevel->bits < fewest_map_bits) {
+                fewest_map_bits = maplevel->bits;
+                basemap = subfile;
+            }
+            ++subfile;
+        }
+
+        /* Add all basemap levels to the list. */
+        QVector<subfile_desc_t::maplevel_t>::const_iterator maplevel = basemap->maplevels.begin();
+        while(maplevel != basemap->maplevels.end()) {
+            if (!maplevel->inherited) {
                 map_level_t ml;
                 ml.bits  = maplevel->bits;
                 ml.level = maplevel->level;
@@ -456,19 +477,37 @@ bool CGarminDBMap::registerMap(map_t& map)
             CGarminImg img(0);
             img.load(map.tiles.begin()->file,true);
 
-            const QMap<QString,subfile_desc_t>& subfiles                 = img.getSubFiles();
-            QMap<QString,subfile_desc_t>::const_iterator subfile         = subfiles.begin();
-            QVector<subfile_desc_t::maplevel_t>::const_iterator maplevel = subfile->maplevels.begin();
-            while(maplevel != subfile->maplevels.end()) {
-                if(!maplevel->inherited) {
-                    map_level_t ml;
-                    ml.bits  = maplevel->bits;
-                    ml.level = maplevel->level;
-                    ml.useBaseMap = false;
-                    map.maplevels << ml;
+            const QMap<QString,subfile_desc_t>& subfiles = img.getSubFiles();
+            QMap<QString,subfile_desc_t>::const_iterator subfile = subfiles.begin();
+            /*
+             * Query all subfiles for possible maplevels.
+             * Exclude basemap to avoid polution.
+             */
+            while (subfile != subfiles.end()) {
+                QVector<subfile_desc_t::maplevel_t>::const_iterator maplevel = subfile->maplevels.begin();
+                /* Skip basemap. */
+                if (subfile == basemap) {
+                    ++subfile;
+                    continue;
                 }
-                ++maplevel;
+                while (maplevel != subfile->maplevels.end()) {
+                    if (!maplevel->inherited) {
+                        map_level_t ml;
+                        ml.bits  = maplevel->bits;
+                        ml.level = maplevel->level;
+                        ml.useBaseMap = false;
+                        map.maplevels << ml;
+                    }
+                    ++maplevel;
+                }
+                ++subfile;
             }
+            /* Sort all entries, note that stable sort should insure that basemap is preferred when available. */
+            qStableSort(map.maplevels.begin(), map.maplevels.end(), CGarminDBMap::map_level_t::GreaterThan);
+            /* Delete any duplicates for obvious performance reasons. */
+            QVector<map_level_t>::iterator where;
+            where = std::unique(map.maplevels.begin(), map.maplevels.end());
+            map.maplevels.erase(where, map.maplevels.end());
             map.isTransparent = img.isTransparent();
         }
         catch(exce_garmin_t e) {
@@ -1326,3 +1365,8 @@ void CGarminDBMap::saveGPX(CGpx& gpx)
         ++map;
     }
 }
+
+bool CGarminDBMap::map_level_t::GreaterThan(const CGarminDBMap::map_level_t &ml1, const CGarminDBMap::map_level_t &ml2)
+{
+    return ml1.bits < ml2.bits;
+}
