@@ -24,6 +24,7 @@
 #include "CGarminImg.h"
 #include "IProjection.h"
 #include "GarminIcons.h"
+#include "CCanvas.h"
 
 #define MAX_IDX_ZOOM 34
 #define MIN_IDX_ZOOM 0
@@ -840,6 +841,8 @@ void CGarminMap::drawBackground(QPainter * p)
         p = &paintBottom;
     }
 
+//     p->setRenderHint(QPainter::Antialiasing,true);
+
     // draw active map
     const QList<CGarminImg*>& mapFiles = gpResources->mapdb().getVisibleTiles(CGarminDBMap::eMap);
     QList<CGarminImg*>::const_iterator file = mapFiles.begin();
@@ -1456,8 +1459,7 @@ void CGarminMap::drawPoint(const QPointF& pt, const CGarminPoint& point, QPainte
                 p.drawEllipse((int)pt.x() - 1 ,(int)pt.y() - 1,3,3);
 
                 if(scale < 5.0) {
-                    p.setPen(Qt::darkBlue);
-                    p.drawText(pt + QPoint(2,-2), point.label1());
+                    CCanvas::drawText(point.label1(),p,(pt + QPoint(0,-2)).toPoint());
                 }
 
                 break;
@@ -1578,8 +1580,7 @@ void CGarminMap::drawPoint(const QPointF& pt, const CGarminPoint& point, QPainte
                 p.drawEllipse((int)pt.x() - 1 ,(int)pt.y() - 1,3,3);
 
                 if(scale < 2.0) {
-                    p.setPen(Qt::darkBlue);
-                    p.drawText(pt + QPoint(2,-2), point.label1());
+                    CCanvas::drawText(point.label1(),p, (pt + QPoint(0,-2)).toPoint());
                 }
 
                 break;
@@ -1594,8 +1595,7 @@ void CGarminMap::drawPoint(const QPointF& pt, const CGarminPoint& point, QPainte
 
                 if(scale < 2.0) {
                     p.drawPixmap(pt + QPoint(-7,-7),QPixmap(":/icons/wpt/parking15x15.png"));
-                    p.setPen(Qt::darkBlue);
-                    p.drawText(pt + QPoint(10,0), point.label1());
+                    CCanvas::drawText(point.label1(), p, (pt + QPoint(0,-2)).toPoint());
                 }
 
         }
@@ -1636,8 +1636,7 @@ void CGarminMap::drawPoint(const QPointF& pt, const CGarminPoint& point, QPainte
                 p.drawEllipse((int)pt.x() - 1 ,(int)pt.y() - 1,3,3);
 
                 if(scale < 5.0) {
-                    p.setPen(Qt::darkBlue);
-                    p.drawText(pt + QPoint(2,-2), point.label1());
+                    CCanvas::drawText(point.label1(), p, (pt + QPoint(0,-2)).toPoint());
                 }
 
                 break;
@@ -1660,9 +1659,7 @@ void CGarminMap::drawPoint(const QPointF& pt, const CGarminPoint& point, QPainte
                 p.setBrush(Qt::cyan);
                 p.drawEllipse((int)pt.x() - 1 ,(int)pt.y() - 1,3,3);
                 if(scale < 5.0) {
-                    p.setPen(Qt::darkBlue);
-                    p.drawText(pt + QPoint(2,-2), point.label1());
-                }
+                    CCanvas::drawText(point.label1(), p, (pt + QPoint(0,-2)).toPoint());                }
                 break;
         }
         return;
@@ -1750,8 +1747,7 @@ void CGarminMap::drawPoint(const QPointF& pt, const CGarminPoint& point, QPainte
             p.setBrush(QColor("#846030"));
             p.drawEllipse((int)pt.x() - 1 ,(int)pt.y() - 1,3,3);
             if(scale < 5.0) {
-                p.setPen(Qt::darkBlue);
-                p.drawText(pt + QPoint(2,-2), point.label1());
+                CCanvas::drawText(point.label1(), p, (pt + QPoint(0,-2)).toPoint());
             }
             break;
 
@@ -1764,8 +1760,7 @@ void CGarminMap::drawPoint(const QPointF& pt, const CGarminPoint& point, QPainte
             p.drawEllipse((int)pt.x() - 1 ,(int)pt.y() - 1,3,3);
             if(scale < 5.0) {
                 p.drawPixmap(pt + QPoint(-7,-7),QPixmap(":/icons/wpt/summit15x15.png"));
-                p.setPen(Qt::darkBlue);
-                p.drawText(pt + QPoint(10,0), point.label1());
+                CCanvas::drawText(point.label1(), p, (pt + QPoint(0,-2)).toPoint());
             }
             break;
 
