@@ -215,18 +215,18 @@ void CDevice::_acquire()
         throw exce_t(errSync,msg);
     }
 
-    if(devid) {
-        if(usb->getProductId() != devid) {
-            string msg = "No " + devname + " unit detected. Please retry to select other device driver.";
-            throw exce_t(errSync,msg);
-        }
-    }
-    else {
-        if(usb->getProductId() != 0x0124 && usb->getProductId() != 0x0272) {
-            string msg = "No " + devname + " unit detected. Please retry to select other device driver.";
-            throw exce_t(errSync,msg);
-        }
-    }
+//     if(devid) {
+//         if(usb->getProductId() != devid) {
+//             string msg = "No " + devname + " unit detected. Please retry to select other device driver.";
+//             throw exce_t(errSync,msg);
+//         }
+//     }
+//     else {
+//         if(usb->getProductId() != 0x0124 && usb->getProductId() != 0x0272 && usb->getProductId() !=0x0312 && usb->getProductId() !=0x02B7) {
+//             string msg = "No " + devname + " unit detected. Please retry to select other device driver.";
+//             throw exce_t(errSync,msg);
+//         }
+//     }
 }
 
 
